searchNodes=[{"type":"module","title":"Fuzler","doc":"A lightweight, reusable cache built on an ETS table, wrapped in a GenServer . Highlights Named ETS – give any atom as :table . Public reads / protected writes – :public , read_concurrency: &amp; write_concurrency: enabled; only the owner process mutates the table. O(1) table lookup – mapping from server‐name → table stored in :persistent_term , avoiding a GenServer.call/2 round‑trip for every public\u00A0API invocation. Hot reload, insert, get, predicate stream – as before. Fuzzy full‑text search on keys – text_search/3 uses String.jaro_distance/2 (or any custom scorer) and thresholding.","ref":"Fuzler.html"},{"type":"function","title":"Fuzler.child_spec/1","doc":"Returns a specification to start this module under a supervisor. See Supervisor .","ref":"Fuzler.html#child_spec/1"},{"type":"function","title":"Fuzler.get/2","doc":"Fetches value for key , or nil if not present.","ref":"Fuzler.html#get/2"},{"type":"function","title":"Fuzler.insert/2","doc":"Inserts a {key, value} tuple into the cache.","ref":"Fuzler.html#insert/2"},{"type":"function","title":"Fuzler.nif_similarity_score/2","doc":"","ref":"Fuzler.html#nif_similarity_score/2"},{"type":"function","title":"Fuzler.reload/1","doc":"Reloads the cache by wiping the table and invoking the loader again.","ref":"Fuzler.html#reload/1"},{"type":"function","title":"Fuzler.start_link/1","doc":"Starts the cache. Options: :table – required atom, the ETS table name. :loader – required () -&gt; Enumerable.t() that yields {key, value} . :ets_opts – extra ETS options merged with sensible defaults [:named_table, :public, read_concurrency: true, write_concurrency: true] . :name – process name (defaults to the module itself).","ref":"Fuzler.html#start_link/1"},{"type":"function","title":"Fuzler.stream/2","doc":"Returns a lazy stream of {key, value} pairs whose value satisfies predicate.(value) . When no predicate given, returns every entry.","ref":"Fuzler.html#stream/2"},{"type":"function","title":"Fuzler.text_search/3","doc":"Top‐N fuzzy search selecting the scorer based on table size: If the cache has fewer than @key_count_threshold entries, uses pure‐Elixir String.jaro_distance/2 . Otherwise uses the SIMD‐accelerated nif_similarity_score/2 . query – the search string. opts – :limit (default 15). Returns a list of {key, value, score} sorted by descending similarity.","ref":"Fuzler.html#text_search/3"},{"type":"type","title":"Fuzler.key/0","doc":"","ref":"Fuzler.html#t:key/0"},{"type":"opaque","title":"Fuzler.t/0","doc":"","ref":"Fuzler.html#t:t/0"},{"type":"type","title":"Fuzler.value/0","doc":"","ref":"Fuzler.html#t:value/0"},{"type":"extras","title":"Fuzler","doc":"Fuzler is a lightweight, reusable cache built on top of an ETS table and wrapped in a GenServer , with built‑in fuzzy text search powered by a Rust NIF for high-performance similarity scoring.","ref":"readme.html"},{"type":"extras","title":"Fuzler - Features","doc":"Named ETS table : Give any atom as :table . Public reads / protected writes : ETS is :public with concurrency options; only the GenServer process can write. O(1) lookup : Table name → ETS table mapping stored in :persistent_term , avoiding extra GenServer calls. Hot reload : reload/1 clears and repopulates from your loader function. Insert / Get / Stream : Standard cache operations. Fuzzy full-text search : text_search/3 returns top‑N {key, value, score} suggestions using a SIMD‑accelerated Rust NIF.","ref":"readme.html#features"},{"type":"extras","title":"Fuzler - Installation","doc":"Add fuzler to your dependencies in mix.exs : def deps do [ { :fuzler , git : &quot;https://github.com/elchemista/fuzler.git&quot; } ] end Then fetch and compile: mix deps.get mix compile Make sure you have Rust installed; the Rustler NIF will compile automatically.","ref":"readme.html#installation"},{"type":"extras","title":"Fuzler - Quickstart","doc":"1. Start the cache loader = fn -&gt; [ { &quot;apple&quot; , %{ id : 1 } } , { &quot;banana&quot; , %{ id : 2 } } , { &quot;cantaloupe&quot; , %{ id : 3 } } ] end { :ok , _pid } = Fuzler . start_link ( table : :fruit_cache , loader : loader , name : :my_cache ) 2. Basic operations # Get a value Fuzler . get ( &quot;banana&quot; ) #⇒ %{id: 2} # Insert a new item Fuzler . insert ( { &quot;durian&quot; , %{ id : 4 } } ) Fuzler . get ( &quot;durian&quot; ) #⇒ %{id: 4} # Reload all data Fuzler . reload ( :my_cache ) # Stream entries matching predicate Fuzler . stream ( fn %{ id : id } -&gt; id &lt;= 2 end ) |&gt; Enum . map ( &amp; elem ( &amp;1 , 0 ) ) #⇒ [&quot;apple&quot;, &quot;banana&quot;] 3. Fuzzy text search # Suggest keys similar to &quot;ap&quot; Fuzler . text_search ( &quot;ap&quot; , limit : 5 ) #⇒ [ # {&quot;apple&quot;, %{id: 1}, 1.0}, # {&quot;grape&quot;, %{id: 7}, 0.75}, # ... #] Options : :limit – maximum results (default: 15) :threshold – minimum score (default: 0.10) :keys – pre-collected list of keys to search (avoids re-scanning ETS)","ref":"readme.html#quickstart"},{"type":"extras","title":"Fuzler - Module API","doc":"@spec start_link ( opts :: keyword ( ) ) :: GenServer . on_start ( ) @spec reload ( server \\ server ( ) ) :: :ok @spec insert ( { key , value } , server ) :: :ok @spec get ( key , server ) :: value | nil @spec stream ( ( value -&gt; boolean ) , server ) :: Enumerable . t ( ) @spec text_search ( String . t ( ) , keyword ( ) , server ) :: [ { key , value , float ( ) } ]","ref":"readme.html#module-api"},{"type":"extras","title":"Fuzler - Running tests","doc":"mix test # runs Elixir tests","ref":"readme.html#running-tests"},{"type":"extras","title":"Fuzler - License","doc":"MIT License","ref":"readme.html#license"},{"type":"extras","title":"LICENSE","doc":"MIT License Copyright (c) 2025 elchemista Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation files (the &quot;Software&quot;), to deal in the Software without restriction, including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions: The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software. THE SOFTWARE IS PROVIDED &quot;AS IS&quot;, WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.","ref":"license.html"}]